Struct VacantEntry
struct VacantEntry<'a, K, V, S> { ... }
A view into a vacant entry in a LiteMap.
Implementations
impl<'a, K, V, S> VacantEntry<'a, K, V, S>
fn key(self: &Self) -> &KGets a reference to the key that would be used when inserting a value through the
VacantEntry.fn insert(self: Self, value: V) -> &'a mut VSets the value of the entry with the
VacantEntry's key, and returns a mutable reference to it.
impl<'a, K, V, S> Freeze for VacantEntry<'a, K, V, S>
impl<'a, K, V, S> RefUnwindSafe for VacantEntry<'a, K, V, S>
impl<'a, K, V, S> Send for VacantEntry<'a, K, V, S>
impl<'a, K, V, S> Sync for VacantEntry<'a, K, V, S>
impl<'a, K, V, S> Unpin for VacantEntry<'a, K, V, S>
impl<'a, K, V, S> UnsafeUnpin for VacantEntry<'a, K, V, S>
impl<'a, K, V, S> UnwindSafe for VacantEntry<'a, K, V, S>
impl<K, V, S> Debug for VacantEntry<'_, K, V, S>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T> Any for VacantEntry<'a, K, V, S>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for VacantEntry<'a, K, V, S>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for VacantEntry<'a, K, V, S>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for VacantEntry<'a, K, V, S>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for VacantEntry<'a, K, V, S>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for VacantEntry<'a, K, V, S>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for VacantEntry<'a, K, V, S>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>