Enum Entry
enum Entry<'a, K, V, S>
An entry in a LiteMap, which may be either occupied or vacant.
Variants
-
Occupied(OccupiedEntry<'a, K, V, S>) -
Vacant(VacantEntry<'a, K, V, S>)
Implementations
impl<'a, K, V, S> Entry<'a, K, V, S>
fn or_insert(self: Self, default: V) -> &'a mut VEnsures a value is in the entry by inserting the default value if empty, and returns a mutable reference to the value in the entry.
fn or_default(self: Self) -> &'a mut V where V: DefaultEnsures a value is in the entry by inserting the result of the default function if empty, and returns a mutable reference to the value in the entry.
fn or_insert_with<F: FnOnce() -> V>(self: Self, default: F) -> &'a mut VEnsures a value is in the entry by inserting the result of the default function if empty, and returns a mutable reference to the value in the entry.
fn and_modify<F>(self: Self, f: F) -> Self where F: FnOnce(&mut V)Provides in-place mutable access to an occupied entry before any potential inserts into the map.
impl<'a, K, V, S> Freeze for Entry<'a, K, V, S>
impl<'a, K, V, S> RefUnwindSafe for Entry<'a, K, V, S>
impl<'a, K, V, S> Send for Entry<'a, K, V, S>
impl<'a, K, V, S> Sync for Entry<'a, K, V, S>
impl<'a, K, V, S> Unpin for Entry<'a, K, V, S>
impl<'a, K, V, S> UnsafeUnpin for Entry<'a, K, V, S>
impl<'a, K, V, S> UnwindSafe for Entry<'a, K, V, S>
impl<K, V, S> Debug for Entry<'_, K, V, S>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T> Any for Entry<'a, K, V, S>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Entry<'a, K, V, S>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Entry<'a, K, V, S>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for Entry<'a, K, V, S>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for Entry<'a, K, V, S>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Entry<'a, K, V, S>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Entry<'a, K, V, S>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>