Trait StoreIntoIterator
trait StoreIntoIterator<K, V>: StoreMut<K, V>
Associated Types
type KeyValueIntoIter: TraitBound { trait_: Path { path: "Iterator", id: Id(348), args: Some(AngleBracketed { args: [], constraints: [AssocItemConstraint { name: "Item", args: None, binding: Equality(Type(Tuple([Generic("K"), Generic("V")]))) }] }) }, generic_params: [], modifier: None }
Required Methods
fn lm_into_iter(self: Self) -> <Self as >::KeyValueIntoIterReturns an iterator that moves every item from this store.
Provided Methods
fn lm_extend_end(self: &mut Self, other: Self) where Self: SizedAdds items from another store to the end of this store.
fn lm_extend_start(self: &mut Self, other: Self) where Self: SizedAdds items from another store to the beginning of this store.
Implementors
impl<K, V> StoreIntoIterator for Vec<(K, V)>