Trait StoreMut
trait StoreMut<K, V>: Store<K, V>
Required Methods
fn lm_with_capacity(capacity: usize) -> SelfCreates a new store with the specified capacity hint.
Implementations may ignore the argument if they do not support pre-allocating capacity.
fn lm_reserve(self: &mut Self, additional: usize)Reserves additional capacity in the store.
Implementations may ignore the argument if they do not support pre-allocating capacity.
fn lm_get_mut(self: &mut Self, index: usize) -> Option<(&K, &mut V)>Gets a key/value pair at the specified index, with a mutable value.
fn lm_push(self: &mut Self, key: K, value: V)Pushes one additional item onto the store.
fn lm_insert(self: &mut Self, index: usize, key: K, value: V)Inserts an item at a specific index in the store.
Panics
Panics if
indexis greater than the length.fn lm_remove(self: &mut Self, index: usize) -> (K, V)Removes an item at a specific index in the store.
Panics
Panics if
indexis greater than the length.fn lm_clear(self: &mut Self)Removes all items from the store.
Implementors
impl<K, V> StoreMut for Vec<(K, V)>